==> jlibs-xsd-2.2.3-sources.jar: jlibs/xml/xsd/EmptySampleValueGenerator.java <==
/**
 * Copyright 2015 Santhosh Kumar Tekuri
 *
 * The JLibs authors license this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package jlibs.xml.xsd;

import org.apache.xerces.xs.XSAttributeDeclaration;
import org.apache.xerces.xs.XSElementDeclaration;
import org.apache.xerces.xs.XSSimpleTypeDefinition;
import org.apache.xerces.xs.XSTypeDefinition;

/**
 * @author Santhosh Kumar Tekuri
 */
public class EmptySampleValueGenerator implements XSInstance.SampleValueGenerator{
    public static final EmptySampleValueGenerator INSTANCE = new EmptySampleValueGenerator();

    private EmptySampleValueGenerator(){}

    @Override
    public String generateSampleValue(XSElementDeclaration element, XSSimpleTypeDefinition simpleType){
        return "";
    }

    @Override
    public String generateSampleValue(XSAttributeDeclaration attribute, XSSimpleTypeDefinition simpleType){
        return "";
    }

    @Override
    public XSTypeDefinition selectSubType(XSElementDeclaration element) {
        return null;
    }
}

==> jlibs-xsd-3.0.1-sources.jar: jlibs/xml/xsd/EmptySampleValueGenerator.java <==
/**
 * Copyright 2015 Santhosh Kumar Tekuri
 *
 * The JLibs authors license this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package jlibs.xml.xsd;

import org.apache.xerces.xs.XSAttributeDeclaration;
import org.apache.xerces.xs.XSElementDeclaration;
import org.apache.xerces.xs.XSSimpleTypeDefinition;
import org.apache.xerces.xs.XSTypeDefinition;

import jlibs.core.graph.Path;

/**
 * @author Santhosh Kumar Tekuri
 */
public class EmptySampleValueGenerator implements XSInstance.SampleValueGenerator{
    public static final EmptySampleValueGenerator INSTANCE = new EmptySampleValueGenerator();

    private EmptySampleValueGenerator(){}

    @Override
    public String generateSampleValue(XSElementDeclaration element, XSSimpleTypeDefinition simpleType, Path path){
        return "";
    }

    @Override
    public String generateSampleValue(XSAttributeDeclaration attribute, XSSimpleTypeDefinition simpleType, Path path){
        return "";
    }

    @Override
    public XSTypeDefinition selectSubType(XSElementDeclaration element) {
        return null;
    }
}
